@@ -61,7 +61,6 @@ private:
     void publishWKS();
     void publishPKS();
 
-private Q_SLOTS:
     void onWKSPublishingCheckDone(const GpgME::Error &error, const QByteArray &returnedData, const QByteArray &returnedError);
     void onWKSPublishingRequestCreated(const GpgME::Error &error, const QByteArray &returnedData, const QByteArray &returnedError);
     void onWKSPublishingRequestSent(KJob *job);
@@ -69,7 +68,7 @@ private Q_SLOTS:
     void onPKSPublishingFinished(int result, QProcess::ExitStatus status);
 
 private:
-    int m_transportId;
+    int m_transportId = 0;
     GpgME::Key m_key;
     QString m_mailbox;
     QPointer<QObject> mJob;
