@@ -40,25 +40,23 @@ public:
     void leavePageNext() override;
     void leavePageNextRequested() override;
 
-private Q_SLOTS:
+Q_SIGNALS:
+    void manualWanted(bool);
+
+private:
     void ispdbSearchFinished(bool ok);
     void slotTextChanged();
     void slotCreateAccountClicked();
     void slotRadioButtonClicked(QAbstractButton *button);
     void slotSearchType(const QString &);
-
-Q_SIGNALS:
-    void manualWanted(bool);
-
-private:
     void automaticConfigureAccount();
     void configureSmtpAccount();
     void configureImapAccount();
     void configurePop3Account();
 
     Ui::PersonalDataPage ui;
-    Ispdb *mIspdb;
-    SetupManager *mSetupManager;
+    Ispdb *mIspdb = nullptr;
+    SetupManager *mSetupManager = nullptr;
 };
 
 #endif
